@@ -53,7 +53,6 @@ typedef struct av_req_data{
      char *clientip;
 } av_req_data_t;
 
-static ci_off_t MAX_OBJECT_SIZE = 5*1024*1024;
 static int SEND_PERCENT_BYTES = 0;
 static ci_off_t START_SEND_AFTER = 1;
 
@@ -179,9 +178,6 @@ int squidclamav_init_service(ci_service_xdata_t * srv_xdata,
 	return 0;
     }
 
-    if (maxsize)
-	MAX_OBJECT_SIZE = maxsize;
-
     return 1;
 }
 
@@ -203,8 +199,6 @@ void cfgreload_command(char *name, int type, char **argv)
     memset(clamd_curr_ip, 0, sizeof(clamd_curr_ip));
     if (load_patterns() == 0)
        ci_debug_printf(0, "FATAL cfgreload_command: reload configuration command failed!\n");
-    if (maxsize)
-       MAX_OBJECT_SIZE = maxsize;
     if (squidclamav_xdata)
        set_istag(squidclamav_xdata);
 
@@ -445,7 +439,7 @@ int squidclamav_check_preview_handler(char *preview_data, int preview_data_len,
 	data->clientip = NULL;
      }
 
-     data->body = ci_simple_file_new(MAX_OBJECT_SIZE);
+     data->body = ci_simple_file_new(maxsize);
      if (SEND_PERCENT_BYTES >= 0 && START_SEND_AFTER == 0) {
 	ci_req_unlock_data(req);
 	ci_simple_file_lock_all(data->body);
@@ -476,7 +470,7 @@ int squidclamav_read_from_net(char *buf, int len, int iseof, ci_request_t * req)
 	return ci_simple_file_write(data->body, buf, len, iseof);
     }
 
-    if (ci_simple_file_size(data->body) >= MAX_OBJECT_SIZE) {
+    if ((maxsize > 0) && (ci_simple_file_size(data->body) >= maxsize)) {
 	data->no_more_scan = 1;
 	ci_req_unlock_data(req);
 	ci_simple_file_unlock_all(data->body);
